==> xcsoar-6.8.10.tar.xz: xcsoar-6.8.10/src/Engine/Contest/ContestResult.hpp <==
/* Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef CONTEST_RESULT_HPP
#define CONTEST_RESULT_HPP

#include "Math/fixed.hpp"

#include <type_traits>

struct ContestResult
{
  /** Score (pts) according to OLC rule */
  fixed score;
  /** Optimum distance (m) travelled according to OLC rule */
  fixed distance;
  /** Time (s) of optimised OLC path */
  fixed time;

  void Reset() {
    score = fixed(0);
    distance = fixed(0);
    time = fixed(0);
  }

  bool IsDefined() const {
    return positive(score);
  }

  /**
   * Returns the average speed on the optimised path [m/s].  Returns
   * zero if the result is invalid.
   */
  gcc_pure
  fixed GetSpeed() const {
    return positive(time)
      ? distance / time
      : fixed(0);
  }
};

static_assert(std::is_trivial<ContestResult>::value, "type is not trivial");

#endif

==> xcsoar-7.9.tar.xz: xcsoar-7.9/src/Engine/Contest/ContestResult.hpp <==
/* Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef CONTEST_RESULT_HPP
#define CONTEST_RESULT_HPP

#include <type_traits>

struct ContestResult
{
  /** Score (pts) according to contest rule */
  double score;
  /** Optimum distance (m) travelled according to contest rule */
  double distance;
  /** Time (s) of optimised OLC path */
  double time;

  constexpr void Reset() noexcept {
    score = 0;
    distance = 0;
    time = 0;
  }

  constexpr bool IsDefined() const noexcept {
    return score > 0;
  }

  /**
   * Returns the average speed on the optimised path [m/s].  Returns
   * zero if the result is invalid.
   */
  constexpr double GetSpeed() const noexcept {
    return time > 0
      ? distance / time
      : 0.;
  }
};

static_assert(std::is_trivial<ContestResult>::value, "type is not trivial");

#endif
